@@ -1,5 +1,6 @@
 import tensorflow as tf
 
+import keras_cortex.layers
 from keras_cortex.cornet.util import Identity
 
 
@@ -67,7 +68,7 @@ class CORBlockS(tf.keras.Model):
         return output
 
 
-def CORNetS(output_dim: int = 10):
+def CORNetS(output_dim: int = 10, name="CORNetS"):
     model = tf.keras.Sequential([
         tf.keras.Sequential([
             tf.keras.layers.ZeroPadding2D((3, 3)),
@@ -88,7 +89,7 @@ def CORNetS(output_dim: int = 10):
         CORBlockS(128, 256, times=4, name='V4'),
         CORBlockS(256, 512, times=2, name='IT'),
         tf.keras.Sequential([
-            tf.keras.layers.AveragePooling2D(1, name='avgpool'),
+            keras_cortex.layers.SpatialSoftmax(),
             tf.keras.layers.Flatten(name='flatten'),
             tf.keras.layers.Dense(output_dim, name='linear'),
             Identity(name="output")
