@@ -20,7 +20,12 @@ class SpatialSoftmax(tf.keras.layers.Layer):
         posx, posy = tf.meshgrid(tf.linspace(-1., 1., num=H),
                                  tf.linspace(-1., 1., num=W))
 
-        self.image_coords = tf.cast(tf.stack([posx, posy], axis=-1), dtype=self.compute_dtype)
+        image_coords = tf.stack([posx, posy], axis=-1)
+        self.image_coords = self.add_weight(
+            "image_coords",
+            initializer=tf.keras.initializers.constant(image_coords),
+            shape=image_coords.shape,
+            trainable=False)
 
     def call(self, inputs, **kwargs):
         N, H, W, C = list(inputs.shape)
